if not SinnerFrame then
   CreateFrame("Frame", "SinnerFrame", UIParent)
end

local SinnerMainFrame  = CreateFrame("Frame", "SinnerMainFrame", UIParent)
SinnerMainFrame.width  = 200
SinnerMainFrame.height = 250
SinnerMainFrame:SetFrameStrata("FULLSCREEN_DIALOG")
SinnerMainFrame:SetSize(SinnerMainFrame.width, SinnerMainFrame.height)
SinnerMainFrame:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
SinnerMainFrame:SetBackdrop({
	bgFile   = "Interface\\DialogFrame\\UI-DialogBox-Background",
	--edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
	tile     = true,
	tileSize = 32,
	edgeSize = 32,
	insets   = { left = 8, right = -10, top = -2, bottom = 8 }
})
SinnerMainFrame:SetBackdropColor(0, 0, 0, 1)
SinnerMainFrame:EnableMouse(true)
SinnerMainFrame:EnableMouseWheel(true)

-- Make movable/resizable
SinnerMainFrame:SetMovable(true)
SinnerMainFrame:SetResizable(enable)
SinnerMainFrame:SetMinResize(100, 100)
SinnerMainFrame:RegisterForDrag("LeftButton")
SinnerMainFrame:SetScript("OnDragStart", SinnerMainFrame.StartMoving)
SinnerMainFrame:SetScript("OnDragStop", SinnerMainFrame.StopMovingOrSizing)

tinsert(UISpecialFrames, "SinnerMainFrame")

-- Close button
local closeButton = CreateFrame("Button", nil, SinnerMainFrame, "UIPanelButtonTemplate")
closeButton:SetPoint("BOTTOMRIGHT", 10, 10)
closeButton:SetHeight(25)
closeButton:SetWidth(70)
closeButton:SetText(CLOSE)
closeButton:SetScript("OnClick", function(self)
	HideParentPanel(self)
end)
SinnerMainFrame.closeButton = closeButton

local checkOpt = CreateFrame("CheckButton", "OptionsCheckButton", SinnerMainFrame, "UIPanelButtonTemplate")
checkOpt:SetPoint("BOTTOMLEFT", 10, 10)
checkOpt:SetNormalTexture("")
checkOpt:SetHeight(25)
checkOpt:SetWidth(25)
checkOpt:SetText("tt")


-- ScrollingMessageFrame
local SinnerMessageFrame = CreateFrame("ScrollingMessageFrame", nil, SinnerMainFrame)
SinnerMessageFrame:SetPoint("CENTER", 15, 20)
SinnerMessageFrame:SetSize(SinnerMainFrame.width, SinnerMainFrame.height - 50)
SinnerMessageFrame:SetFontObject(GameFontNormal)
SinnerMessageFrame:SetTextColor(1, 1, 1, 1) -- default color
SinnerMessageFrame:SetJustifyH("LEFT")
SinnerMessageFrame:SetHyperlinksEnabled(true)
SinnerMessageFrame:SetFading(false)
SinnerMessageFrame:SetMaxLines(300)
SinnerMainFrame.SinnerMessageFrame = SinnerMessageFrame

local SinnerScrollBar = CreateFrame("Slider", nil, SinnerMainFrame, "UIPanelScrollBarTemplate")
SinnerScrollBar:SetPoint("RIGHT", SinnerMainFrame, "RIGHT", 35, 0)
SinnerScrollBar:SetSize(30, SinnerMainFrame.height - 50)
SinnerScrollBar:SetMinMaxValues(0, 9)
SinnerScrollBar:SetValueStep(1)
SinnerScrollBar.scrollStep = 1
SinnerMainFrame.SinnerScrollBar = SinnerScrollBar

SinnerScrollBar:SetScript("OnValueChanged", function(self, value)
	SinnerMessageFrame:SetScrollOffset(select(2, SinnerScrollBar:GetMinMaxValues()) - value)
end)

SinnerScrollBar:SetValue(select(2, SinnerScrollBar:GetMinMaxValues()))

SinnerMainFrame:SetScript("OnMouseWheel", function(self, delta)
	--print(messageFrame:GetNumMessages(), messageFrame:GetNumLinesDisplayed())

	local cur_val = SinnerScrollBar:GetValue()
	local min_val, max_val = SinnerScrollBar:GetMinMaxValues()

	if delta < 0 and cur_val < max_val then
		cur_val = math.min(max_val, cur_val + 1)
		SinnerScrollBar:SetValue(cur_val)
	elseif delta > 0 and cur_val > min_val then
		cur_val = math.max(min_val, cur_val - 1)
		SinnerScrollBar:SetValue(cur_val)
	end
end)

local SinnerDropDown = CreateFrame("Button", "DropDownMenu", SinnerMainFrame, "UIDropDownMenuTemplate")
SinnerDropDown:ClearAllPoints()
SinnerDropDown:SetPoint("TOP", 0, 20)

 
local dropdownitems = {}
 
local function OnClick(self)
   UIDropDownMenu_SetSelectedID(SinnerDropDown, self:GetID())
end
 
local function initialize(self, level)
   local info = UIDropDownMenu_CreateInfo()
   for k,v in pairs(dropdownitems) do
      info = UIDropDownMenu_CreateInfo()
      info.text = v
      info.value = v
      info.func = OnClick
      UIDropDownMenu_AddButton(info, level)
   end
end
 
 
UIDropDownMenu_Initialize(SinnerDropDown, initialize)
UIDropDownMenu_SetWidth(SinnerDropDown, 100);
UIDropDownMenu_SetButtonWidth(SinnerDropDown, 124)
UIDropDownMenu_SetSelectedID(SinnerDropDown, 1)
UIDropDownMenu_JustifyText(SinnerDropDown, "LEFT")

local optionsPanel = CreateFrame("FRAME")
optionsPanel.name = "Sinner"
InterfaceOptions_AddCategory(optionsPanel)


local usedHS = {} 						-- ppl who used a HS
local usedPot = {} 						-- ppl who used a Pot
local roster = {"Nookio", "Gamer", "Jakob", "Kza", "Romberg", "Raiser", "Gresh", "Getrekt", "Ursarus", "Morkon", "Empy", "Cloud", "Lnycher", "Tivaah", "Ziemlichlangerkackname", "Mitsi", "Twaja", "Narvik", "Tavis", "Spieler", "Auchnspieler", "nochnspieler"} 						-- array with all players
local used = {} 						-- ppl who tried not to die
local didntuse = {}						-- ppl who wanted to die

local nHS = 0 							-- number of taken Healthstones
local nPot = 0 							-- number of taken Pots
local nMember = 0						-- number of ppl in raid
local nTaken = 0						-- number of ppl who took a Pot or HS
local zoneID
local first = true


function realmsplit(inputstr, sep) -- Deletes the "-Realm"-Part in "Name-Realm" // e.g. "Shogio-Gul'dan" -> "Shogio"
    if sep == nil then
        sep = "-"
    end
	if inputstr ~= nil then
		local t={} ; i=1
		for str in string.gmatch(inputstr, "([^"..sep.."]+)") do
			t[i] = str
			i = i + 1
		end
		return t[1]
	end
end

function concatnames(inputarray)

	local t = { }
    for k,v in ipairs(inputarray) do
        t[#t+1] = tostring(v)
    end
    return table.concat(t," ")

end

function removedup(inputarray)

	local outputarray = {}
	local i = 1
	local j = 1
	local nEntries = #inputarray
	local duplicate = false
	local checkentry
	local nOut = 1
	
	while i <= nEntries do
	checkentry = inputarray[i]
	
		while j <= nEntries do
		
			if i ~= j then
				if inputarray[i] == inputarray[j] then
					duplicate = true
					
				end
			end
			j=j+1
		end
		
		if not duplicate then
			
			outputarray[nOut] = checkentry
			nOut = nOut +1
		end
		j=i+1
		i=i+1
		duplicate = false
	end
	
	return outputarray

end


 
SinnerFrame:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
SinnerFrame:RegisterEvent("ENCOUNTER_START")
SinnerFrame:RegisterEvent("ENCOUNTER_END")
SinnerFrame:RegisterEvent("PLAYER_REGEN_ENABLED")
SinnerFrame:RegisterEvent("PLAYER_REGEN_DISABLED")

SinnerFrame:SetScript("OnEvent", function(self, event, ...)
	zoneID = GetCurrentMapAreaID()
	if(zoneID == 1052 or zoneID == 1094 or zoneID == 1114 or zoneID == 1088 or zoneID == 1147) then
		if event == "ENCOUNTER_START" then
		--if event == "PLAYER_REGEN_DISABLED" then
			nMember = GetNumGroupMembers()
			
			if not first then
				SinnerMessageFrame:Clear()
				--print("erste")
			end
			
			first = false
			local encountername = select(2, ...)
			
			
			
			
			
			
			local i = 1
			while i <= nMember do
				local name, rank, grp, lvl, class, filename, zone, online, isDead, role, isML = GetRaidRosterInfo(i)
				roster[i] = realmsplit(name)
				i = i+1
			end
			
			table.insert(dropdownitems, 1, encountername)
			local function initialize(self, level)
				local info = UIDropDownMenu_CreateInfo()
				for k,v in pairs(dropdownitems) do
					info = UIDropDownMenu_CreateInfo()
					info.text = v
					info.value = v
					info.func = OnClick
					UIDropDownMenu_AddButton(info, level)
				end
			end
			
		end
		

		if event == "COMBAT_LOG_EVENT_UNFILTERED" then
				local CombatEvent = select(2, ...)
				local SpellName = select(13, ...) 
				local TSourceName = select(5, ...)
				local SourceName = realmsplit(TSourceName)
				local SpellID = select(12, ...)
					
			
			if CombatEvent == "SPELL_HEAL" then
					
				if (SpellID == 6262) then -- HealthStone 6262 // 185123
					
					nHS = nHS + 1
					usedHS[nHS] = SourceName
					nTaken = nTaken + 1
					used[nTaken] = SourceName
					
									
					
				end
			
				if (SpellID == 188016) then -- Ancient Healing Pot 188016 // 213243
					
					nPot = nPot + 1
					nTaken = nTaken +1
					usedPot[nPot] = SourceName
					used[nTaken] = SourceName
					
					
				end
			end
			
		end
		
		if event == "ENCOUNTER_END" then
		--if event == "PLAYER_REGEN_ENABLED" then
			
			-- remove duplicate entries (hello warlocks!)
			used = removedup(used)
			usedHS = removedup(usedHS)
			roster = removedup(roster)	
			
			
			-- lets check who wanted to die
					
			
			local checkName
			local check = false
			local j = 1
			local k = 1
			local l = 1
			
			
			
			
			
			while j <= #roster do
			checkName = roster[j]
				while k <= #used do
					
					if roster[j] == used[k] then
						check = true
						break
					end
					
					k = k + 1
				end
				
				if check == false then
					didntuse[l] = checkName
					if j~= #roster then 
						l = l+1
					end
				end
					
				k = 1
				check = false
				j = j+1
				
			end
			
			-- Print Results
			
			SinnerMessageFrame:AddMessage("")
			if encountername ~= nil then
				SinnerMessageFrame:AddMessage("Fight versus" .. encountername)
			else
				SinnerMessageFrame:AddMessage("DEBUG: Puppenkampf!!")
			end
			
			if nHS ~= 0 then
				SinnerMessageFrame:AddMessage("|cffFF0000Healthstone:")
				SinnerMessageFrame:AddMessage(concatnames(usedHS))
				SinnerMessageFrame:AddMessage("")
			end
				
			if nPot ~= 0 then
				SinnerMessageFrame:AddMessage("|cffFF0000Healing Potion:")
				SinnerMessageFrame:AddMessage(concatnames(usedPot))
				SinnerMessageFrame:AddMessage("")
			end
									
			SinnerMessageFrame:AddMessage("|cffFF0000Nothing:")
			SinnerMessageFrame:AddMessage(concatnames(didntuse))
			SinnerMessageFrame:AddMessage("")
			
			
		
					
			-- ReSet everything to 0
			
			nPot = 0
			nHS = 0
			nMember = 0
			
			used = {}
			usedHS = {}
			usedPot = {}
			didntuse = {}
			roster = {}
			collectgarbage()
			
						
		
		end
		
		
		
	end		
	
end)

SLASH_SINNER1 = "/sinner"
SlashCmdList.SINNER = function(arg)
	if arg == "toggle" or arg == "show" or arg == "hide" or arg =="" then
		if SinnerMainFrame:IsShown() then
			SinnerMainFrame:Hide()
			print("hide")
		else
			SinnerMainFrame:Show()
			print("show")
		end
		
	elseif arg == "help" then
		print("|cffFF0000Sinner|cffFFFFFF toggle: Shows/Hides the main frame.")
		
		
	else
		print("|cffFF0000Sinner|cffFFFFFF ".. arg .. ": command unknown - type '/Sinner help' for available options ")
		
	end
end
 